YARP 2.3.1 (2010-09-21)                                                {#v2_3_1}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.0...v2.3.1`):

```
   143	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    15	Lorenzo Natale <lorenzo.natale@iit.it>
    12	Alessandro Scalzo <alessandro.scalzo@iit.it>
    12	Marco Randazzo <marco.randazzo@iit.it>
     3	Giacomo Spigler <spiglerg@gmail.com>
     3	Giorgio Metta <giorgio.metta@iit.it>
     3	Ugo Pattacini <ugo.pattacini@iit.it>
     2	Arjan Gijsberts <arjan.gijsberts@idiap.ch>
     2	Bruno Nery <brunonery@brunonery.com>
     2	Daniel Krieg <krieg@fias.uni-frankfurt.de>
     1	Ze Ji <z.ji@herts.ac.uk>
```
